import { Plugin } from 'esbuild';
import { LogLevel } from './logger.cjs';

interface ScriptableDeployOptions {
    /**
     * Log level for the plugin
     * 'auto' will use esbuild's logLevel
     * Default: 'auto'
     */
    logLevel?: LogLevel | 'auto';
    /**
     * Whether to continue building when deployment fails
     * Default: true
     */
    continueOnError?: boolean;
    /**
     * Custom Scriptable directory path
     * If not specified, will automatically search in iCloud Drive
     */
    scriptableDir?: string;
    /**
     * Source file patterns to match entry points
     * Default: ['**\/*.{ts,tsx,js,jsx}']
     * Examples:
     * -'**\/*.widget.ts'         //only deploy widget files
     * -['**\/*.ts', '!**\/*.test.ts'] //exclude test files
     */
    patterns?: string | string[];
    /**
     * Whether to add Scriptable banner from manifest
     * Default: true
     */
    addBanner?: boolean;
    /**
     * Custom manifest file extensions
     * Default: ['.manifest.json', '.manifest', '.json']
     */
    manifestExtensions?: string[];
}
declare function scriptableDeploy(options?: ScriptableDeployOptions): Plugin;

export { type ScriptableDeployOptions, scriptableDeploy };
